V256

Struct V256 

pub struct V256 { /* private fields */ }
The Keccak sponge function is defined in Algorithm 8 from FIPS 202. The implementation here is split between the Self::absorb() and Self::squeeze() and specialized for Keccak-256.

Implementations

Source

impl V256

pub const fn new() -> Self

Creates a new sponge with the specified rate and domain separator.

pub const fn absorb(self, data: &[u8]) -> Self

Absorb some data into the sponge.

pub const fn squeeze(self) -> [u8; 32]

Write the domain separation string, pad the input to the sponge, and squeeze the digest from the sponge. See Appendix B.2 from FIPS 202.